@@ -180,7 +180,8 @@ ggbarplot <- function(background, df, dfby, xvar, f_axis, s_axis, color_bg, sep_
 
 
 #' @keywords internal
-ggpointline <- function(df, dfby, xvar, y, color, by){
+ggpointline <- function(df, dfby, xvar, y, color, by,
+                        show_total, total_color, total_name){
   if ( by == "NULL"){
     list(
       ggplot2::geom_point(data = df,
@@ -195,6 +196,7 @@ ggpointline <- function(df, dfby, xvar, y, color, by){
       ggplot2::theme_minimal()
     )
   } else {
+    if ( isTRUE(show_total) ){
     list(
       ggplot2::geom_point(data = dfby,
                           aes(x = .data[[xvar]],
@@ -206,8 +208,33 @@ ggpointline <- function(df, dfby, xvar, y, color, by){
                              group = .data[[by]],
                              color = as.factor(.data[[by]]))),
       ggplot2::theme_minimal(),
-      ggplot2::labs(color = by)
-    )
+      ggplot2::labs(color = by, linetype = NULL),
+      ggplot2::geom_point(data = df,
+                          aes(x = .data[[xvar]],
+                              y = .data[[y]]),
+                          color = total_color),
+      ggplot2::geom_line(data = df,
+                         aes(x = .data[[xvar]],
+                             y = .data[[y]],
+                             linetype = total_name,
+                             group = "black"),
+                         color = total_color)
+    )}
+    else {
+      list(
+        ggplot2::geom_point(data = dfby,
+                            aes(x = .data[[xvar]],
+                                y = .data[[y]],
+                                color = .data[[by]])),
+        ggplot2::geom_line(data = dfby,
+                           aes(x = .data[[xvar]],
+                               y = .data[[y]],
+                               group = .data[[by]],
+                               color = as.factor(.data[[by]]))),
+        ggplot2::theme_minimal(),
+        ggplot2::labs(color = by)
+      )
+    }
   }
 }
 
@@ -266,11 +293,15 @@ ggyscale <- function(background, sep_mark){
 
 
 #' @keywords internal
-ggbarline <- function(background, df, dfby, xvar, f_axis, f_axis_name, exposure, color_bg, color, sep_mark, by, labels, sort_manual, label_width){
+ggbarline <- function(background, df, dfby, xvar, f_axis,
+                      f_axis_name, exposure, color_bg, color,
+                      sep_mark, by, labels, sort_manual, label_width,
+                      show_total, total_color, total_name){
   df <- scale_second_axis(background, df, dfby, f_axis, exposure, by)
   ggplot2::ggplot() +
     ggbarplot(background, df, dfby, xvar, f_axis, exposure, color_bg, sep_mark, by) +
-    ggpointline(df, dfby, xvar, f_axis, color, by) +
+    ggpointline(df, dfby, xvar, f_axis, color, by,
+                show_total, total_color, total_name) +
     ggplot2::labs(y = f_axis_name, x = xvar) +
     gglabels(background, labels, df, xvar, sep_mark) +
     ggyscale(background, sep_mark) +
@@ -394,6 +425,37 @@ split_x_fn <- function(data, x, left = NULL, right = NULL){
 }
 
 
+#' @keywords internal
+moments <- function(x, dist = c("gamma", "lognormal")){
+
+  dist <- match.arg(dist)
+  m <- mean(x, na.rm = TRUE)
+  s <- sd(x, na.rm = TRUE)
+  v <- s^2
+
+  if ( dist == "gamma" ){
+    scale <- m ^ 2 / s
+    shape <- s / m
+    return(list(scale = scale, shape = shape))
+  }
+
+  if ( dist == "lognormal" ){
+    meanlog <- log(m ^ 2 / sqrt(v + m ^ 2) )
+    sdlog <- log( v / (m ^ 2) + 1)
+    return(list(meanlog = meanlog, sdlog = sdlog))
+  }
+}
+
+
+##' @keywords internal
+#dtruncated_gamma <- function(x, scale, shape) {
+#  if (!requireNamespace("truncdist", quietly = TRUE)) {
+#    stop("Package \"truncdist\" needed for this function to work. Please install it.",
+#         call. = FALSE)
+#  }
+#  truncdist::dtrunc(x, "gamma", a = left, b = right, scale = scale, shape = shape)
+#}
+
 
 
 
